#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import unittest
import yaml
import amulet
import sys


# Lots of prereqs on this charm (eg: java), so give it a large timeout
seconds_to_wait = 2400

class BundleTest(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
         d = amulet.Deployment()

         local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
         with open(local_path, "r") as fd:
            config = yaml.safe_load(fd)

         url = config.get('wasbase').get('was_url')
         print('Using URL  %s' % url)
         # Test if a IB url for the repository is defined
         if not url:
            print("You need to define a url for the WAS Base packages repository.\n"
                  "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

         pkg = config.get('wasbase').get('im_file_name')
         print('Using IBM IM package %s' % pkg)
         if not pkg:
            print("You need to define a package name for IBM IM.\n"
                  "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

         bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
         with open(bundle_path, 'r') as bundle_file:
            contents = yaml.safe_load(bundle_file)
         d.load(contents)
#       d.add("haproxy")

        bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
        with open(bundle_path, 'r') as bundle_file:
           contents = yaml.safe_load(bundle_file)
        d.load(contents)
        d.add("haproxy")
      
        # Software doesn't actually install until you accept the license
        d.configure('was-base', {'accept-ibm-websphere-license': True, 'accept-ibm-im-license': True,'was_url': url, 'im_file_name': pkg })
        d.setup(seconds_to_wait)
        cls.d = d
        d.relate('haproxy:reverseproxy', 'was-base:website')
        d.sentry.wait(seconds_to_wait)

        d.configure('was-base', {'accept-ibm-websphere-license': True, 'accept-ibm-im-license': True,'was_url': url, 'im_file_name': pkg })
        d.configure('haproxy', {'enable_monitoring': True })
        d.relate('haproxy:reverseproxy', 'was-base:website')
        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d
    def test_deployed(self):
        self.assertTrue(self.d.deployed)

    def test_website(self):
        unit = self.d.sentry.unit['was-base/0']
        url  = 'http://%s:9060/ibm/console' % unit.info['public-address']
        response = requests.get(url)
        # Raise an exception if the url was not a valid web page.
        response.raise_for_status()

    def test_reverseproxy(self):
        unit = self.d.sentry.unit['haproxy/0']
        url  = 'http://%s:80/ibm/console' % unit.info['public-address']
        response = requests.get(url)
        # Raise an exception if the url was not a valid web page.
        response.raise_for_status()

if __name__ == '__main__':
    unittest.main()

